@@ -11,7 +11,9 @@ class NextTransition(object):
 		"""Creates an instance of NextTransition"""
 
 		self.__id = None
+		self.__criteria_matched = None
 		self.__name = None
+		self.__type = None
 		self.__key_modified = dict()
 
 	def get_id(self):
@@ -19,7 +21,7 @@ class NextTransition(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -38,12 +40,36 @@ class NextTransition(object):
 		self.__id = id
 		self.__key_modified['id'] = 1
 
+	def get_criteria_matched(self):
+		"""
+		The method to get the criteria_matched
+
+		Returns:
+			bool: A bool representing the criteria_matched
+		"""
+
+		return self.__criteria_matched
+
+	def set_criteria_matched(self, criteria_matched):
+		"""
+		The method to set the value to criteria_matched
+
+		Parameters:
+			criteria_matched (bool) : A bool representing the criteria_matched
+		"""
+
+		if criteria_matched is not None and not isinstance(criteria_matched, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: criteria_matched EXPECTED TYPE: bool', None, None)
+		
+		self.__criteria_matched = criteria_matched
+		self.__key_modified['criteria_matched'] = 1
+
 	def get_name(self):
 		"""
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -62,6 +88,30 @@ class NextTransition(object):
 		self.__name = name
 		self.__key_modified['name'] = 1
 
+	def get_type(self):
+		"""
+		The method to get the type
+
+		Returns:
+			string: A string representing the type
+		"""
+
+		return self.__type
+
+	def set_type(self, type):
+		"""
+		The method to set the value to type
+
+		Parameters:
+			type (string) : A string representing the type
+		"""
+
+		if type is not None and not isinstance(type, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
+		
+		self.__type = type
+		self.__key_modified['type'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
@@ -70,7 +120,7 @@ class NextTransition(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
