@@ -22,7 +22,7 @@ class Query(object):
 		The method to get the module
 
 		Returns:
-			string: A string value
+			Module: An instance of Module
 		"""
 
 		return self.__module
@@ -32,11 +32,16 @@ class Query(object):
 		The method to set the value to module
 
 		Parameters:
-			module (string) : A string representing the module
+			module (Module) : An instance of Module
 		"""
 
-		if module is not None and not isinstance(module, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module EXPECTED TYPE: str', None, None)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.modules import Module
+		except Exception:
+			from ..modules import Module
+
+		if module is not None and not isinstance(module, Module):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module EXPECTED TYPE: Module', None, None)
 		
 		self.__module = module
 		self.__key_modified['module'] = 1
@@ -46,7 +51,7 @@ class Query(object):
 		The method to get the cvid
 
 		Returns:
-			string: A string value
+			string: A string representing the cvid
 		"""
 
 		return self.__cvid
@@ -94,7 +99,7 @@ class Query(object):
 		The method to get the page
 
 		Returns:
-			int: A int value
+			int: An int representing the page
 		"""
 
 		return self.__page
@@ -150,7 +155,7 @@ class Query(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
