@@ -14,17 +14,20 @@ class CustomView(object):
 		self.__name = None
 		self.__system_name = None
 		self.__display_value = None
-		self.__shared_type = None
+		self.__access_type = None
 		self.__category = None
 		self.__sort_by = None
 		self.__sort_order = None
 		self.__favorite = None
-		self.__offline = None
 		self.__default = None
 		self.__system_defined = None
 		self.__criteria = None
-		self.__shared_details = None
+		self.__shared_to = None
 		self.__fields = None
+		self.__modified_time = None
+		self.__modified_by = None
+		self.__last_accessed_time = None
+		self.__created_by = None
 		self.__key_modified = dict()
 
 	def get_id(self):
@@ -32,7 +35,7 @@ class CustomView(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -56,7 +59,7 @@ class CustomView(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -80,7 +83,7 @@ class CustomView(object):
 		The method to get the system_name
 
 		Returns:
-			string: A string value
+			string: A string representing the system_name
 		"""
 
 		return self.__system_name
@@ -104,7 +107,7 @@ class CustomView(object):
 		The method to get the display_value
 
 		Returns:
-			string: A string value
+			string: A string representing the display_value
 		"""
 
 		return self.__display_value
@@ -123,36 +126,36 @@ class CustomView(object):
 		self.__display_value = display_value
 		self.__key_modified['display_value'] = 1
 
-	def get_shared_type(self):
+	def get_access_type(self):
 		"""
-		The method to get the shared_type
+		The method to get the access_type
 
 		Returns:
-			string: A string value
+			string: A string representing the access_type
 		"""
 
-		return self.__shared_type
+		return self.__access_type
 
-	def set_shared_type(self, shared_type):
+	def set_access_type(self, access_type):
 		"""
-		The method to set the value to shared_type
+		The method to set the value to access_type
 
 		Parameters:
-			shared_type (string) : A string representing the shared_type
+			access_type (string) : A string representing the access_type
 		"""
 
-		if shared_type is not None and not isinstance(shared_type, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: shared_type EXPECTED TYPE: str', None, None)
+		if access_type is not None and not isinstance(access_type, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: access_type EXPECTED TYPE: str', None, None)
 		
-		self.__shared_type = shared_type
-		self.__key_modified['shared_type'] = 1
+		self.__access_type = access_type
+		self.__key_modified['access_type'] = 1
 
 	def get_category(self):
 		"""
 		The method to get the category
 
 		Returns:
-			string: A string value
+			string: A string representing the category
 		"""
 
 		return self.__category
@@ -176,7 +179,7 @@ class CustomView(object):
 		The method to get the sort_by
 
 		Returns:
-			string: A string value
+			string: A string representing the sort_by
 		"""
 
 		return self.__sort_by
@@ -200,7 +203,7 @@ class CustomView(object):
 		The method to get the sort_order
 
 		Returns:
-			string: A string value
+			string: A string representing the sort_order
 		"""
 
 		return self.__sort_order
@@ -224,7 +227,7 @@ class CustomView(object):
 		The method to get the favorite
 
 		Returns:
-			int: A int value
+			int: An int representing the favorite
 		"""
 
 		return self.__favorite
@@ -243,36 +246,12 @@ class CustomView(object):
 		self.__favorite = favorite
 		self.__key_modified['favorite'] = 1
 
-	def get_offline(self):
-		"""
-		The method to get the offline
-
-		Returns:
-			bool: A bool value
-		"""
-
-		return self.__offline
-
-	def set_offline(self, offline):
-		"""
-		The method to set the value to offline
-
-		Parameters:
-			offline (bool) : A bool representing the offline
-		"""
-
-		if offline is not None and not isinstance(offline, bool):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: offline EXPECTED TYPE: bool', None, None)
-		
-		self.__offline = offline
-		self.__key_modified['offline'] = 1
-
 	def get_default(self):
 		"""
 		The method to get the default
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the default
 		"""
 
 		return self.__default
@@ -296,7 +275,7 @@ class CustomView(object):
 		The method to get the system_defined
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the system_defined
 		"""
 
 		return self.__system_defined
@@ -344,29 +323,29 @@ class CustomView(object):
 		self.__criteria = criteria
 		self.__key_modified['criteria'] = 1
 
-	def get_shared_details(self):
+	def get_shared_to(self):
 		"""
-		The method to get the shared_details
+		The method to get the shared_to
 
 		Returns:
 			list: An instance of list
 		"""
 
-		return self.__shared_details
+		return self.__shared_to
 
-	def set_shared_details(self, shared_details):
+	def set_shared_to(self, shared_to):
 		"""
-		The method to set the value to shared_details
+		The method to set the value to shared_to
 
 		Parameters:
-			shared_details (list) : An instance of list
+			shared_to (list) : An instance of list
 		"""
 
-		if shared_details is not None and not isinstance(shared_details, list):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: shared_details EXPECTED TYPE: list', None, None)
+		if shared_to is not None and not isinstance(shared_to, list):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: shared_to EXPECTED TYPE: list', None, None)
 		
-		self.__shared_details = shared_details
-		self.__key_modified['shared_details'] = 1
+		self.__shared_to = shared_to
+		self.__key_modified['shared_to'] = 1
 
 	def get_fields(self):
 		"""
@@ -392,6 +371,116 @@ class CustomView(object):
 		self.__fields = fields
 		self.__key_modified['fields'] = 1
 
+	def get_modified_time(self):
+		"""
+		The method to get the modified_time
+
+		Returns:
+			datetime: An instance of datetime
+		"""
+
+		return self.__modified_time
+
+	def set_modified_time(self, modified_time):
+		"""
+		The method to set the value to modified_time
+
+		Parameters:
+			modified_time (datetime) : An instance of datetime
+		"""
+
+		from datetime import datetime
+
+		if modified_time is not None and not isinstance(modified_time, datetime):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
+		
+		self.__modified_time = modified_time
+		self.__key_modified['modified_time'] = 1
+
+	def get_modified_by(self):
+		"""
+		The method to get the modified_by
+
+		Returns:
+			User: An instance of User
+		"""
+
+		return self.__modified_by
+
+	def set_modified_by(self, modified_by):
+		"""
+		The method to set the value to modified_by
+
+		Parameters:
+			modified_by (User) : An instance of User
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.users import User
+		except Exception:
+			from ..users import User
+
+		if modified_by is not None and not isinstance(modified_by, User):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
+		
+		self.__modified_by = modified_by
+		self.__key_modified['modified_by'] = 1
+
+	def get_last_accessed_time(self):
+		"""
+		The method to get the last_accessed_time
+
+		Returns:
+			datetime: An instance of datetime
+		"""
+
+		return self.__last_accessed_time
+
+	def set_last_accessed_time(self, last_accessed_time):
+		"""
+		The method to set the value to last_accessed_time
+
+		Parameters:
+			last_accessed_time (datetime) : An instance of datetime
+		"""
+
+		from datetime import datetime
+
+		if last_accessed_time is not None and not isinstance(last_accessed_time, datetime):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: last_accessed_time EXPECTED TYPE: datetime', None, None)
+		
+		self.__last_accessed_time = last_accessed_time
+		self.__key_modified['last_accessed_time'] = 1
+
+	def get_created_by(self):
+		"""
+		The method to get the created_by
+
+		Returns:
+			User: An instance of User
+		"""
+
+		return self.__created_by
+
+	def set_created_by(self, created_by):
+		"""
+		The method to set the value to created_by
+
+		Parameters:
+			created_by (User) : An instance of User
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.users import User
+		except Exception:
+			from ..users import User
+
+		if created_by is not None and not isinstance(created_by, User):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_by EXPECTED TYPE: User', None, None)
+		
+		self.__created_by = created_by
+		self.__key_modified['created_by'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
@@ -400,7 +489,7 @@ class CustomView(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
