@@ -19,7 +19,7 @@ class NotesOperations(object):
 		"""Creates an instance of NotesOperations"""
 		pass
 
-	def get_notes(self, param_instance, header_instance):
+	def get_notes(self, param_instance=None, header_instance=None):
 		"""
 		The method to get notes
 
@@ -42,12 +42,12 @@ class NotesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
-		handler_instance.header = header_instance
+		api_path = api_path + '/crm/v2.1/Notes'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.response_handler import ResponseHandler
 		except Exception:
@@ -78,13 +78,13 @@ class NotesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/Notes'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -115,20 +115,20 @@ class NotesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/Notes'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_notes(self, param_instance):
+	def delete_notes(self, param_instance=None):
 		"""
 		The method to delete notes
 
@@ -147,23 +147,25 @@ class NotesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.param = param_instance
+		api_path = api_path + '/crm/v2.1/Notes'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def get_note(self, id):
+	def get_note(self, id, param_instance=None, header_instance=None):
 		"""
 		The method to get note
 
 		Parameters:
 			id (int) : An int representing the id
+			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -175,26 +177,34 @@ class NotesOperations(object):
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes/'
+		api_path = api_path + '/crm/v2.1/Notes/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_note(self, request, id):
+	def update_note(self, id, request):
 		"""
 		The method to update note
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -208,21 +218,21 @@ class NotesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes/'
+		api_path = api_path + '/crm/v2.1/Notes/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -248,11 +258,11 @@ class NotesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Notes/'
+		api_path = api_path + '/crm/v2.1/Notes/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -263,6 +273,7 @@ class NotesOperations(object):
 class GetNotesParam(object):
 	page = Param('page', 'com.zoho.crm.api.Notes.GetNotesParam')
 	per_page = Param('per_page', 'com.zoho.crm.api.Notes.GetNotesParam')
+	fields = Param('fields', 'com.zoho.crm.api.Notes.GetNotesParam')
 
 
 class GetNotesHeader(object):
@@ -271,3 +282,11 @@ class GetNotesHeader(object):
 
 class DeleteNotesParam(object):
 	ids = Param('ids', 'com.zoho.crm.api.Notes.DeleteNotesParam')
+
+
+class GetNoteParam(object):
+	fields = Param('fields', 'com.zoho.crm.api.Notes.GetNoteParam')
+
+
+class GetNoteHeader(object):
+	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Notes.GetNoteHeader')
