@@ -4,7 +4,8 @@ from .transfer_action_handler import TransferActionHandler
 from .transfer_action_response import TransferActionResponse
 from .forecast_category import ForecastCategory
 from .body_wrapper import BodyWrapper
-from .pipeline_operations import PipelineOperations, TransferAndDeleteParam, GetPipelinesParam, CreatePipelinesParam, UpdatePipelinesParam, PatchPipelinesParam, GetPipelineParam, UpdatePipelineParam
+from .transfer_pipe_line import TransferPipeLine
+from .pipeline_operations import PipelineOperations, TransferAndDeleteParam, GetPipelinesParam, CreatePipelinesParam, UpdatePipelinesParam, GetPipelineParam, UpdatePipelineParam
 from .pipeline import Pipeline
 from .transfer_and_delete_wrapper import TransferAndDeleteWrapper
 from .api_exception import APIException
