@@ -12,7 +12,6 @@ class BodyWrapper(object):
 
 		self.__data = None
 		self.__trigger = None
-		self.__process = None
 		self.__duplicate_check_fields = None
 		self.__wf_trigger = None
 		self.__lar_id = None
@@ -66,30 +65,6 @@ class BodyWrapper(object):
 		self.__trigger = trigger
 		self.__key_modified['trigger'] = 1
 
-	def get_process(self):
-		"""
-		The method to get the process
-
-		Returns:
-			list: An instance of list
-		"""
-
-		return self.__process
-
-	def set_process(self, process):
-		"""
-		The method to set the value to process
-
-		Parameters:
-			process (list) : An instance of list
-		"""
-
-		if process is not None and not isinstance(process, list):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: process EXPECTED TYPE: list', None, None)
-		
-		self.__process = process
-		self.__key_modified['process'] = 1
-
 	def get_duplicate_check_fields(self):
 		"""
 		The method to get the duplicate_check_fields
@@ -119,7 +94,7 @@ class BodyWrapper(object):
 		The method to get the wf_trigger
 
 		Returns:
-			string: A string value
+			string: A string representing the wf_trigger
 		"""
 
 		return self.__wf_trigger
@@ -143,7 +118,7 @@ class BodyWrapper(object):
 		The method to get the lar_id
 
 		Returns:
-			string: A string value
+			string: A string representing the lar_id
 		"""
 
 		return self.__lar_id
@@ -170,7 +145,7 @@ class BodyWrapper(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
