@@ -15,7 +15,7 @@ class TagsOperations(object):
 		"""Creates an instance of TagsOperations"""
 		pass
 
-	def get_tags(self, param_instance):
+	def get_tags(self, param_instance=None):
 		"""
 		The method to get tags
 
@@ -34,18 +34,18 @@ class TagsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		api_path = api_path + '/crm/v2.1/settings/tags'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def create_tags(self, request, param_instance):
+	def create_tags(self, request, param_instance=None):
 		"""
 		The method to create tags
 
@@ -73,21 +73,21 @@ class TagsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/settings/tags'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def update_tags(self, request, param_instance):
+	def update_tags(self, request, param_instance=None):
 		"""
 		The method to update tags
 
@@ -115,28 +115,28 @@ class TagsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/settings/tags'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def update_tag(self, request, param_instance, id):
+	def update_tag(self, id, request, param_instance=None):
 		"""
 		The method to update tag
 
 		Parameters:
+			id (int) : An int representing the id
 			request (BodyWrapper) : An instance of BodyWrapper
 			param_instance (ParameterMap) : An instance of ParameterMap
-			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -150,25 +150,25 @@ class TagsOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
-		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags/'
+		api_path = api_path + '/crm/v2.1/settings/tags/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
@@ -194,24 +194,24 @@ class TagsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags/'
+		api_path = api_path + '/crm/v2.1/settings/tags/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def merge_tags(self, request, id):
+	def merge_tags(self, id, request):
 		"""
 		The method to merge tags
 
 		Parameters:
-			request (MergeWrapper) : An instance of MergeWrapper
 			id (int) : An int representing the id
+			request (MergeWrapper) : An instance of MergeWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -225,37 +225,37 @@ class TagsOperations(object):
 		except Exception:
 			from .merge_wrapper import MergeWrapper
 
-		if request is not None and not isinstance(request, MergeWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MergeWrapper', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if request is not None and not isinstance(request, MergeWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MergeWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags/'
+		api_path = api_path + '/crm/v2.1/settings/tags/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/merge'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def add_tags_to_record(self, param_instance, module_api_name, record_id):
+	def add_tags_to_record(self, record_id, module_api_name, param_instance=None):
 		"""
 		The method to add tags to record
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string representing the module_api_name
 			record_id (int) : An int representing the record_id
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -264,41 +264,41 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		if not isinstance(record_id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(record_id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(record_id)
 		api_path = api_path + '/actions/add_tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
 			from .record_action_handler import RecordActionHandler
 		return handler_instance.api_call(RecordActionHandler.__module__, 'application/json')
 
-	def remove_tags_from_record(self, param_instance, module_api_name, record_id):
+	def remove_tags_from_record(self, record_id, module_api_name, param_instance=None):
 		"""
 		The method to remove tags from record
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string representing the module_api_name
 			record_id (int) : An int representing the record_id
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -307,40 +307,40 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		if not isinstance(record_id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(record_id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(record_id)
 		api_path = api_path + '/actions/remove_tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
 			from .record_action_handler import RecordActionHandler
 		return handler_instance.api_call(RecordActionHandler.__module__, 'application/json')
 
-	def add_tags_to_multiple_records(self, param_instance, module_api_name):
+	def add_tags_to_multiple_records(self, module_api_name, param_instance=None):
 		"""
 		The method to add tags to multiple records
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -349,35 +349,35 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/add_tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
 			from .record_action_handler import RecordActionHandler
 		return handler_instance.api_call(RecordActionHandler.__module__, 'application/json')
 
-	def remove_tags_from_multiple_records(self, param_instance, module_api_name):
+	def remove_tags_from_multiple_records(self, module_api_name, param_instance=None):
 		"""
 		The method to remove tags from multiple records
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -386,35 +386,35 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/remove_tags'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.param = param_instance
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
 			from .record_action_handler import RecordActionHandler
 		return handler_instance.api_call(RecordActionHandler.__module__, 'application/json')
 
-	def get_record_count_for_tag(self, param_instance, id):
+	def get_record_count_for_tag(self, id, param_instance=None):
 		"""
 		The method to get record count for tag
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			id (int) : An int representing the id
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -423,21 +423,21 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/tags/'
+		api_path = api_path + '/crm/v2.1/settings/tags/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/records_count'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.count_handler import CountHandler
 		except Exception:
