@@ -81,7 +81,7 @@ class Theme(object):
 		The method to get the new_background
 
 		Returns:
-			string: A string value
+			string: A string representing the new_background
 		"""
 
 		return self.__new_background
@@ -105,7 +105,7 @@ class Theme(object):
 		The method to get the background
 
 		Returns:
-			string: A string value
+			string: A string representing the background
 		"""
 
 		return self.__background
@@ -129,7 +129,7 @@ class Theme(object):
 		The method to get the screen
 
 		Returns:
-			string: A string value
+			string: A string representing the screen
 		"""
 
 		return self.__screen
@@ -153,7 +153,7 @@ class Theme(object):
 		The method to get the type
 
 		Returns:
-			string: A string value
+			string: A string representing the type
 		"""
 
 		return self.__type
@@ -180,7 +180,7 @@ class Theme(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
