@@ -250,13 +250,13 @@ class JSONConverter(Converter):
                 if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
                     primary_keys[name] = True
 
-        for key_name, key_detail in class_detail.items():
-            name = key_detail[Constants.NAME]
-            if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
-                required_keys[name] = True
+            for key_name, key_detail in class_detail.items():
+                name = key_detail[Constants.NAME]
+                if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
+                    required_keys[name] = True
 
-            if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
-                primary_keys[name] = True
+                if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
+                    primary_keys[name] = True
 
         for key_name in key_modified.keys():
             if key_modified.get(key_name) != 1:
@@ -380,6 +380,7 @@ class JSONConverter(Converter):
 
     def get_wrapped_response(self, response, pack):
         try:
+            print (response.json())
             return self.get_response(response.json(), pack)
 
         except ValueError:
@@ -507,7 +508,8 @@ class JSONConverter(Converter):
         member_value = None
 
         if key_data is not None:
-            data_type = member_detail[Constants.TYPE]
+
+            data_type = member_detail.get(Constants.TYPE)
 
             if data_type == Constants.LIST_NAMESPACE:
                 member_value = self.get_collections_data(key_data, member_detail)
@@ -517,7 +519,7 @@ class JSONConverter(Converter):
 
             elif data_type == Constants.CHOICE_NAMESPACE or (
                     Constants.STRUCTURE_NAME in member_detail and member_detail[
-                Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
+                    Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
                 member_value = self.__get_choice_instance(key_data)
 
             elif Constants.STRUCTURE_NAME in member_detail and Constants.MODULE in member_detail:
@@ -652,10 +654,8 @@ class JSONConverter(Converter):
                         data_type = Constants.LIST_NAMESPACE
 
                     if data_type == member_detail[Constants.TYPE] or (
-                            member_detail[Constants.TYPE] in Constants.TYPE_VS_DATATYPE and isinstance(key_data,
-                                                                                                       Constants.TYPE_VS_DATATYPE[
-                                                                                                           member_detail[
-                                                                                                               Constants.TYPE]])):
+                            member_detail[Constants.TYPE] in Constants.DATA_TYPE and isinstance(key_data, Constants.DATA_TYPE.get(member_detail[Constants.TYPE]))):
+
                         matches += 1
 
                     elif member_detail[Constants.TYPE] == Constants.CHOICE_NAMESPACE:
@@ -676,13 +676,15 @@ class JSONConverter(Converter):
 
         return matches / total_points
 
-    def build_name(self, member_name):
+    @staticmethod
+    def build_name(member_name):
         name_split = str(member_name).split('_')
         sdk_name = name_split[0].lower()
 
         if len(name_split) > 1:
             for i in range(1, len(name_split)):
-                sdk_name += '_' + name_split[i].lower()
+                if len(name_split[i]) > 0:
+                    sdk_name += '_' + name_split[i].lower()
 
         return sdk_name
 
@@ -694,7 +696,8 @@ class JSONConverter(Converter):
 
         return class_holder()
 
-    def module_to_class(self, module_name):
+    @staticmethod
+    def module_to_class(module_name):
         class_name = module_name
 
         if "_" in module_name:
@@ -707,10 +710,12 @@ class JSONConverter(Converter):
 
         return class_name
 
-    def construct_private_member(self, class_name, member_name):
+    @staticmethod
+    def construct_private_member(class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    def __get_choice_instance(self, data):
+    @staticmethod
+    def __get_choice_instance(data):
         choice_split = Constants.CHOICE_NAMESPACE.rpartition('.')
         imported_module = importlib.import_module(choice_split[0])
         class_holder = getattr(imported_module, choice_split[-1])
